/*AtoD.h
analog do digital converter header file
Nathan Z. Gustavson
emac.inc
9/10/02
*/

/*! @defgroup AtoD Analog to Digital module

    This module is the Analog to Digital driver. It provides a sample/callback API that allows users to
    sample the AtoD from the background of the project.
 */


#ifndef ATOD_H
#define ATOD_H
#include <GNU_defs.h>
#include <realtime.h>

#define ATDCTL2		*((u8 *)(0x02 + offset))
#define ADPU		0x80
#define AFFC		0x40
#define ASCIE		0x02

#define ATDCTL3		*((u8 *)(0x03 + offset))
#define S8C		0x40


#define ATDCTL4		*((u8 *)(0x04 + offset))
#define PRE12		0x05

#define ATDCTL5		*((u8 *)(0x05 + offset))	
#define SCAN		0x20
#define MULT		0x10		

#define ATDSTAT0	*((u8 *)(0x06 + offset))	
#define ATDSTAT1	*((u8 *)(0x0B + offset))
#define ATDDIEN		*((u8 *)(0x0D + offset))

#define NEW 1
#define OLD 0

/*
addresses of
modules within the module
*/
#define ATDDRxL		(0x11 + offset)
#define ATDDRxH		(0x10 + offset)

/*@{*/

/*! analog to digital callback function.
This is a type of function that can be installed as a callback to an AtoD conversion
@param module the AtoD module the callback originated from 0 or 1
@param *data_array a pointer to the array of data (u16 AtoD[8)
@param *status_array a pointer to the array of flags(u8 AtoDstatus[8)
@param *privatedata a void pointer that can be set to anything.
@see Install_AtoDcallback
*/
typedef void __attribute__((far))(*ATDcallback)(int module,
		volatile u16 *data_array,volatile u8 *status_array,void *privatedata);


/*! Start an AtoD sample
This function starts a single AtoD sample. When it's complete it calls it's callback if it's installed.
Note that samples can be collected faster than interrupts can be processed so if your IPAC is going to do anything but
collect samples it should insert a delay between samplings.
@param module the module to sample
*/
void __attribute__((far))AtoDst_sample(taskdata module);

/*! Install an AtoD callback
This function installs a callback function which is called when an AtoD sample is completed
@param module the module to install the callback on
@param callback the callback function
@privatedata this void pointer can be set to whatever you need, it will be passed to the callback.
*/
void __attribute__((far))Install_AtoDcallback(int module,ATDcallback callback,void *privatedata);

/*! Remove an AtoD callback
This function removes a callback function from an AtoD module
@param module the module to remove the callback from
*/
void __attribute__((far))Remove_AtoDcallback(int module);

/*@}*/
#endif
