/***************************************************************************
                          DS1305RTC.h  -
              Real time clock control functions .
              These functions rely on the SPI module for communication.
                             -------------------
    begin                : Tue Oct 14 2003
    email                : support@emacinc.com
 ***************************************************************************/


#ifndef DS1305RTC_H
#define DS1305RTC_H
#define RTC

#include <GNU_defs.h>
#include <arch/regdefs.h>

/*! @defgroup RTC DS1305 Module
This module provides functions for accessing and controlling a DS1305RTC,
which currently only exists on the iPAC-HCS12
 */
/*@{*/

#define WRITE_OFFSET 0x80
enum registers { SEC,MIN,HOURS,DAY,DATE,MONTH,YEAR,
SEC_ALARM0,MIN_ALARM0,HOUR_ALARM0,DAY_ALARM0, //alarm0
SEC_ALARM1,MIN_ALARM1,HOUR_ALARM1,DAY_ALARM1, //alarm1
CONTROL,STATUS,TRICKLE_CHARGER};

/*CONTROL bits*/
#define EOSC 0x80
#define WP     0x40
#define INTCN 4
#define AIE1   2
#define AIE0   1

#define INT0  0x04
#define INT1  0x08

#define RTC_CS_MASK 0x04
#define RTC_CE_SETUP() DDRK|=RTC_CS_MASK
#define RTC_CE_ON() PORTK|=RTC_CS_MASK
#define RTC_CE_OFF() PORTK&=(~RTC_CS_MASK)


/*! RTC structure containing all the time elements of the clock
*/
typedef struct timestruct {
int seconds;
int minutes;
int hours;
int day;
int date;
int month;
int year;
}timestruct;

/*!Write to a RTC register
@param reg the register to write to(from the enumerated registers above)
@param the data to write to it
@return SUCCESS
*/
int __attribute__((far))RTC_Write_Register(int reg, u8 data);

/*!Read from a RTC register
@param reg he register to write to(from the enumerated registers above)
@return the byte that was read
*/
u8 __attribute__((far))RTC_Read_Register(int reg);

/*!Get the current time from the RTC
This function reads the current time stored in the RTC's internal registers.
Alternatively each individual register can be returned using the RTC_ macros below
@param time a timestructure that GetTime fills with data
@return  SUCCESS
*/
int __attribute__((far))RTC_GetTime(timestruct *time);

/*!Set the current time of the RTC
This function sets the current time stored in the RTC's internal registers.
Alternatively each individual register can be written using the
RTC_Write_Register function.
@param time a timestructure SetTime writes to the clock
@return  SUCCESS
@see RTC_Write_Register function.
*/
int __attribute__((far))RTC_SetTime(timestruct *time);


#define TIME2RTC(data) (((data/10)<<4)+(data%10))
#define RTC2TIME(data) (((data>>4)*10)+(data&0x0f))

#define RTC_SECONDS    RTC_Read_Register(SEC)
#define RTC_MINUTES      RTC_Read_Register(MIN)
#define RTC_HOURS         RTC_Read_Register(HOURS)
#define RTC_DAY             RTC_Read_Register(DAY)
#define RTC_DATE           RTC_Read_Register(DATE)
#define RTC_MONTH        RTC_Read_Register(MONTH)
#define RTC_YEAR           RTC_Read_Register(YEAR)


#define RTC_SET_SECONDS(data)   RTC_Write_Register(SEC,TIME2RTC(data))
#define RTC_SET_MINUTES(data)     RTC_Write_Register(MIN,TIME2RTC(data))
#define RTC_SET_HOURS(data)        RTC_Write_Register(HOURS,TIME2RTC(data))
#define RTC_SET_DAY(data)            RTC_Write_Register(DAY,TIME2RTC(data))
#define RTC_SET_DATE(data)          RTC_Write_Register(DATE,TIME2RTC(data))
#define RTC_SET_MONTH(data)       RTC_Write_Register(MONTH,TIME2RTC(data))
#define RTC_SET_YEAR(data)          RTC_Write_Register(YEAR,TIME2RTC(data))

/*@}*/

#endif
