/*
 * LCD.H
 */

/*! @defgroup LCD LCD functions

    This module provides functions to control an LCD connected to HRD6.
    Currently 2X20 and 4X20 character displays are supported.
    By default IpacInit initializes displays to work in 2X20 mode, if you are using a 4X20 you will have to call
    LCD_SWLine_Mode to access the lower 2 lines.
    These functions run in the foreground and can cause ms wait times, the longest one being the
    LCD_Home function, which takes at least 15ms to complete.
    Also see LCD_printf in Ipac.h for formatted output.
    @see LCD_printf
 */

#define LCDCODE
/*@{*/

/*!get the current cursor postion.
This function returns the current cursor position, the row is the 8MSB, the column is the 8LSB.
@return the cursor position
*/
int __attribute__((far))LCD_Getpos(void);

/*!set the cursor position.
Sets the current cursor position.
@param row the row the new cursor positon will be.
@param column the column the new cursor position will be.
@return 0
*/
char __attribute__((far))LCD_Setpos(char row, char column);


/*!return the cursor to home and clear the screen if clear is set
This function returns the cursor to it's home position, if clear is non zero the screen will be cleared.
This function takes at least 15ms to complete due to a hardware delay.
@param clear If non zero clears the screen.
@return 0
*/
char __attribute__((far))LCD_Home(char clear);

/*!Write a character to the current cursor location
@param chardata the character to write
@return 0
*/
char __attribute__((far))LCD_Putchar(char chardata);


/*!Write a string to the current cursor location
@param strdata the string to write
@return 0
*/
char __attribute__((far))LCD_Putstr(char *strdata);

/*!Turns the backlight on and off
@param back_en ON for on and OFF for off
@return 0
*/
char __attribute__((far))LCD_Backlight(char back_en);

/*!Change the line mode
This changes the number of lines the LCD functions assume the LCD has. By default this is 2.
@param lines the number of lines to use(2 or 4)
@return 0
*/
void __attribute__((far))LCD_SWLine_Mode(int lines);
/*@}*/


