#ifndef PWM_H
#define PWM_H

#include<GNU_defs.h>
#include<realtime.h>

/*! @defgroup pwm Hardware PWMs

    This module contains functions for controlling the hardware PWMs of the IPAC.
    These functions are used to implement the internal DtoA's of the IPAC.
    Although the hardware PWMs are capable of running at higher speeds than the software ICTs they
    have the disadvandage of being codependant on one another. That is, altering the settings of one hardware PWM may alter
    the settings of another, already set PWM. If high frequency PWMs are truly needed then it would probably be more practical to control
    them directly from the registers, so you have a better idea of whats going on.
 */

/*@{*/

/*!Initialize a hardware pwm and configure it to a certain frequency and duty cycle
This does not start the PWM, merely configures it.
@param duty the duty cycle 0-100
@param pwm the pwm to change (PORTP0-7) 6 and 7 are used for DtoA's
@param freq the pwms frequency
*/
void __attribute__((far))InitPWM(int duty,int pwm,unsigned long freq);

/*!start a configured PWM
@param pwm the pwm to start
@see InitPWM
*/
void __attribute__((far))PWMstart(taskdata pwm);
/*!stop a running hardware PWM
@param pwm the pwm to stop
*/
void __attribute__((far))PWMstop(int pwm);

/*@}*/
#endif


