#ifndef RELAY_H
#define RELAY_H

#include <GNU_defs.h>
#include <arch/param.h>

/*Relay.h
*/

/*! @defgroup Relay Digital Control

    This module is the digital port driver. It provides functions to read,write
    and configure the digital ports of the IPAC. It also provides the macros for reading/writing to the PLD
 */



#define PORT2PMASK 0x3f
#define PORT2PHMASK 0xc0
#define PORT2HMASK 0x0c


#define PORT0_IN  PORTA		
#define PORT1_IN  PTIT
#define PORT2_IN  ((PTIP&PORT2PMASK)|((PTIH&PORT2HMASK)<<4))


#define PORT0_OUT(out) {PORTA = out;}
#define PORT1_OUT(out) {PTT = out;}
#define PORT2_OUT(data) {PTP=(data&PORT2PMASK+(PTP&PORT2PHMASK));PTH=PTH&(~PORT2HMASK) + ((data&PORT2PHMASK)>>4);}


#define PORT0CFG_IN DDRA
#define PORT1CFG_IN DDRT
#define PORT2CFG_IN ((DDRP&PORT2PMASK)|((DDRH&PORT2HMASK)<<4))

#define PORT0CFG_OUT(out) {DDRA = out;}
#define PORT1CFG_OUT(out) {DDRT = out;}
#define PORT2CFG_OUT(data) {DDRP=(data&PORT2PMASK+(DDRP&PORT2PHMASK));DDRH=DDRH&(~PORT2HMASK) + ((data&PORT2PHMASK)>>4);}

#define PLDADD_PORT PTJ
#define PLDWR_PORT  PTJ







#define PLD_CS_PORT PTJ
#define PLD_DATA    PORTB
#define PLD_DDR     DDRB 
#define PORT3PORT   PORTE
#define PORT3CFGPORT DDRE
#define PORT3MASK   0x1F


#define ADD_BIT     1
#define WRITE_PIN   2
#define CS_PINMASK  0x80

#define PLD_DDR_IN() PLD_DDR=0
#define PLD_DDR_OUT() PLD_DDR=0xff
#define PLD_ADDRESS(address) {PLDADD_PORT=(address&ADD_BIT)|(PLDADD_PORT&(~ADD_BIT));}
#define PLD_WRITEMODE() (PLDWR_PORT&=~WRITE_PIN)
#define PLD_READMODE() (PLDWR_PORT|=WRITE_PIN)
#define PLD_CS_ON() (PLD_CS_PORT&=~CS_PINMASK)
#define PLD_CS_OFF() (PLD_CS_PORT|=CS_PINMASK)
#define PLD_INIT() {DDRJ|=(ADD_BIT|WRITE_PIN|CS_PINMASK);PLD_DDR_IN();PLD_CS_OFF();}

#define PLD_WRITE(address,data) {PLD_DDR_OUT();PLD_ADDRESS(address);PLD_DATA=data;PLD_WRITEMODE();PLD_CS_ON();PLD_READMODE();PLD_CS_OFF();}
#define PLD_READ(address)


#ifdef REV2PLD
#define PORT3_OUT(data) {PLD_WRITE(1,data);PORT3PORT=(data&PORT3MASK)|(PORT3PORT&(~PORT3MASK));}
#define PORT4_OUT(data) {PLD_WRITE(0,data);}
#define PORT5_OUT(data)

#ifdef MODBUSCODE
#define PORT3_IN (PORT3PORT&PORT3MASK)|(CopData.Holding[3]&(~PORT3MASK))
#define PORT4_IN CopData.Holding[4]
#else
#define PORT3_IN ((PORT3PORT&PORT3MASK)&(~PORT3MASK))
#define PORT4_IN 0
#endif
#define PORT5_IN PLD_read_port(2)

#define PORT3CFG_OUT(data) {PORT3CFGPORT = (data&PORT3MASK)|(PORT3CFGPORT&(~PORT3MASK));}
#define PORT4CFG_OUT(data)
#define PORT5CFG_OUT(data)


#define PORT3CFG_IN (((PORT3CFGPORT&PORT3MASK)|(~PORT3MASK))&0xfc)
#define PORT4CFG_IN 0xff

#define PORT5CFG_IN 0

#else  //rev 3 PLD
#define PORT3_OUT(data)  //this is input only now
#define PORT4_OUT(data) {PLD_WRITE(0,data);Holding[0] = data;} //added holding register
#define PORT5_OUT(data) {PLD_WRITE(1,data);Holding[1] = data;}//PLD address 1 is now byte wide port 5

#define PORT3_IN (PORT3PORT&PORT3MASK)|(PLD_read_port(1)&(~PORT3MASK))//all readable now, PLD at address 1
#define PORT4_IN Holding[0]//no change
#define PORT5_IN Holding[1]//write only now

#define PORT3CFG_OUT(data) //none of these ports are configurable
#define PORT4CFG_OUT(data)
#define PORT5CFG_OUT(data)


#define PORT3CFG_IN 0
#define PORT4CFG_IN 0xff
#define PORT5CFG_IN 0xff
#endif



/*@{*/

#define STATUS_ON()		(STATUS_PORT|=STATUS_MASK)
#define STATUS_OFF()	(STATUS_PORT&=~STATUS_MASK)


/*! Configure to a digital port.

    This function sends one byte of data to a digital ports configuration register.
    The data byte is a bytewise representation of the 8 pins of the port.
    1's set port pins to be outputs and 0's to inputs.

    @param data  the configuration byte
    @param channel the digital port to address, 0-5
*/
int __attribute__((far))port_cfg(unsigned int channel, u8 data);


/*! Output data to a digital port.

    This function sends one byte of data to a digital port.
    The data byte is a bytewise representation of the 8 pins of the port.
    Writing to pins configured as inputs will have no effect until their configuration is changed,
    at which point the written values will take effect. The function essentialy just writes to the data
    registers of the respective ports.

    @param data  the byte to send
    @param channel the digital port to address, 0-5
    @see port_cfg
*/
int __attribute__((far))Digital_out(u8 data,unsigned int channel);


/*! read from a digital port.

    This function reads one byte of data from the IPAC PLD
    This function is called internally by the Digital_in function
    and is not intended to be called directly.

    @param port the digital port to address, 0-5
    @see port_cfg
*/
u8 __attribute__((far))PLD_read_port(int port);


/*! Configure to a digital port.

    This function reads a digital ports configuration register.
    The data byte is a bytewise representation of the 8 pins of the port.
    1's set port pins to be outputs and 0's to inputs.

    @param channel the digital port to address, 0-5
    @see port_cfg
*/
u8 __attribute__((far))read_port_cfg(unsigned int channel);


/*! read from a digital port.

    This function reads one byte of data from a digital port.
    The data byte is a bytewise representation of the 8 pins of the port.
    This function essentialy just reads from the data
    registers of the respective ports.

    @param channel the digital port to address, 0-5
    @see port_cfg
*/
u8 __attribute__((far))Digital_in(unsigned int channel);

/*!Write to a mask of digital ports
This command writes the same data to a bitmask of the digital ports,
from 0x0 for none to 0x1f for all of them.

bit zero is port zero, bit one is port one, etc.
setting the unused bits has no effect
@param data the byte to write to the ports
@param mask the bitmask of the ports
@return SUCCESS
*/
int __attribute__((far))Digital_Mask_Write(int data,u8 mask);

/*!Configure a mask of digital ports
This command sends a configuration byte to a bitmask of the digital ports,
from 0x0 for none to 0x1f for all of them.
bit zero is port zero, bit one is port one, etc.
setting the unused bits has no effect
@param cfg the configuration byte to write to the ports
@param mask the bitmask of the ports
@return SUCCESS
*/
int __attribute__((far))Digital_Mask_Cfg(int cfg,u8 mask);

/*!Initialize PLD holding registers
Zeros the holding registers for the PLD output ports and
resets the PLD outputs to zero.
This is called by IpacInit and should not be called again
@return SUCCESS
@see IpacInit
*/
int __attribute__((far))Init_PLD_Holding(void);

/*@}*/
#endif
