/* param.h - 
   Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.

This file is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

In addition to the permissions in the GNU General Public License, the
Free Software Foundation gives you unlimited permission to link the
compiled version of this file with other programs, and to distribute
those programs without any restriction coming from the use of this
file.  (The General Public License restrictions do apply in other
respects; for example, they cover modification of the file, and
distribution when not linked into another program.)

This file is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#ifndef _M68HC12_RSI_PARAM_H
#define _M68HC12_RSI_PARAM_H

/*EMAC STM-100 board definitions.  */
#define STM100_ARCH

#include "regdefs.h"

#define DIGITALPORTNUM 0
#define IOCNUMPORTS 0
#define PWMNUM 0//not used for this rev of software
#define PWMSYS PWMNUM+IOCNUMPORTS
#define DACPWM0 6
#define DACPWMNUM 0
#define EXDACNUM 0
#define DTOANUM (EXDACNUM+DACPWMNUM)

#undef M6811_DEF_BAUD
#define M6811_DEF_BAUD 0x30            /* 9600 baud.  */

#undef RAM_SIZE
#define RAM_SIZE       0x2000           /* 8Kb of memory  */

#undef ROM_SIZE
#define ROM_SIZE       0x40000           /*256Kb of memory  */

#undef DATA_SIZE
#define DATA_SIZE      RAM_SIZE         /* Data section size.  */

#undef TEXT_SIZE
#define TEXT_SIZE      ROM_SIZE        /* Text section size.  */

#define ATOD_RESOLUTION 1024
#define ANALOG_VCC 		5


#define RS232PORT		0
#define RS422PORT		1
#define RS485PORT		1


#define PORT1BLOCK				PTT
#define PORT1BLOCKCFG			DDRT

#define CTS_DRVL_PORT 			PORT1BLOCK
#define RI_DRVL_PORT			PORT1BLOCK
#define DSR_DRVL_PORT			PORT1BLOCK
#define DCD_DRVL_PORT			PORT1BLOCK
#define VALDAT_RCV_LED_PORT		PORT1BLOCK
#define OUTBOUND_XMT_LED_PORT 	PORT1BLOCK

#define CTS_DRVL_MASK			0x01
#define RTS_INL_MASK			0x02
#define RI_DRVL_MASK			0x04
#define DTR_INL_MASK    		0x08
#define DSR_DRVL_MASK			0x10
#define DCD_DRVL_MASK			0x20
#define VALDAT_RCV_LED_MASK		0x40
#define OUTBOUND_XMT_LED_MASK	0x80

#define PORT2BLOCK				PORTA
#define PORT2BLOCKCFG			DDRA

#define STATUS_CONFIG			PORT2BLOCKCFG

#define MODE_CODE_PORT			PORT2BLOCK
#define ENA_RS232_PORT			PORT2BLOCK
#define ENA4XX_TX_PORT  		PORT2BLOCK
#define ENA_485_RX_PORT			PORT2BLOCK
#define ENA422_RX_PORT			PORT2BLOCK
#define STATUS_PORT 			PORT2BLOCK

#define MODE_CODE2_MASK 		0x01
#define MODE_CODE1_MASK 		0x02
#define STATUS_MASK 			0x04
#define ENA422_RX_MASK			0x08
#define ENA_485_RX_MASK  		0x10
#define ENA4XX_TX_MASK			0x20
#define ENA_RS232_MASK   		0x40
#define RS232_STATUS_MASK 		0x80 

#define OUTBOUND_XMT_LED_ON()	(OUTBOUND_XMT_LED_PORT &=~OUTBOUND_XMT_LED_PORT)
#define OUTBOUND_XMT_LED_OFF()	(OUTBOUND_XMT_LED_PORT |=OUTBOUND_XMT_LED_PORT)
#define	VALDAT_RCV_LED_ON()		(VALDAT_RCV_LED_PORT &=~VALDAT_RCV_LED_MASK)
#define	VALDAT_RCV_LED_OFF()	(VALDAT_RCV_LED_PORT |=VALDAT_RCV_LED_MASK)

#define CANFLECTOR_MODE			(MODE_CODE_PORT&(MODE_CODE1_MASK|MODE_CODE2_MASK))
#define RS232REFLECTION			0
#define RS422REFLECTION			1
#define RS485REFLECTION			2
#define CANREFLECTION			3

static inline void SET_PORT_DIRECTION(void){
	PORT1BLOCKCFG = 0xff&(~(RTS_INL_MASK|DTR_INL_MASK));
	PORT2BLOCKCFG = 0xff&(~(MODE_CODE2_MASK|MODE_CODE1_MASK|RS232_STATUS_MASK));
}

static inline void DISABLE_HANDSHAKING(void){
	PORT1BLOCK = CTS_DRVL_MASK|RI_DRVL_MASK|DSR_DRVL_MASK|DCD_DRVL_MASK;  
}

static inline void RS232_SIGNAL_MODE(void) {
	SET_PORT_DIRECTION();
	DISABLE_HANDSHAKING();
	PORT2BLOCK = ENA_485_RX_MASK|ENA422_RX_MASK;
}

static inline void RS422_SIGNAL_MODE(void) {
	SET_PORT_DIRECTION();
	DISABLE_HANDSHAKING();
	PORT2BLOCK = ENA_RS232_MASK|ENA_485_RX_MASK|ENA4XX_TX_MASK;
}

static inline void RS485_SIGNAL_MODE(void) {
	SET_PORT_DIRECTION();
	DISABLE_HANDSHAKING();  
	PORT2BLOCK = ENA_RS232_MASK|ENA422_RX_MASK|ENA4XX_TX_MASK;
}
	
static inline void CAN_SIGNAL_MODE(void) {
	SET_PORT_DIRECTION();
	DISABLE_HANDSHAKING();  
	PORT2BLOCK = ENA_RS232_MASK|ENA422_RX_MASK|ENA_485_RX_MASK;
}	

static inline unsigned int INPUT_LINE_MAP(void){
	unsigned int lines = PORT2BLOCK;
	lines<<=8;
	lines |= PORT1BLOCK;
	return lines;
}

/**
 * Serial port mappings
 */

/**
 * Traditional RTS signals for 485 are not actually used in the STM-100
 * instead dedicated 485 control lines are used.
 * Because of this, the macro names don't really make sense in this case
 * To clean this, ser.c needs to be modified to use a more generic term for
 * transmit control.
 */
 
#define RTS_ENABLE(port){PORT2BLOCK|=(ENA_485_RX_MASK|ENA4XX_TX_MASK);} //set RTS line to output
#define RTS_ON(port)  	{PORT2BLOCK=(PORT2BLOCK|ENA4XX_TX_MASK)&(~ENA_485_RX_MASK);}
#define RTS_OFF(port) 	{PORT2BLOCK=(PORT2BLOCK|ENA_485_RX_MASK)&(~ENA4XX_TX_MASK);}

#define PORT232 RS232PORT
#define PORT422 RS422PORT
/* Number of COM Ports */
#define NUM_COMPORTS 2

#endif


