/***************************************************************************
                          eeprom.h  - 
                          eeprom function calls.
                          currently there is no eeprom.h,
                          all functions are simply inlines
                             -------------------
    begin                : Thu Nov 4 2005
    email                : ngustavson@emacinc.com
 ***************************************************************************/
 
#ifndef _EEPROM_H
#define _EEPROM_H

#include <arch/param.h>
#include <gnu_defs.h>
#include <clocks.h>
#include <debug.h>


#define EEPROM_ADD 		0x800
#define MAX_EEPROM_CLK 	200000
#define SECTOR_ERASE  	0x40
#define WORD_PROGRAM  	0x20
#define SECTOR_MODIFY 	0x60

#define  ECLKDIV      *(volatile unsigned char *)(IO_BASE + 0x110)	/* eeprom clock divider */
#define  ECNFG        *(volatile unsigned char *)(IO_BASE + 0x113)	/* eeprom configuration register */
#define  EPROT        *(volatile unsigned char *)(IO_BASE + 0x114)	/* eeprom protection register */
#define  ESTAT        *(volatile unsigned char *)(IO_BASE + 0x115)	/* eeprom status register */
#define  ECMD         *(volatile unsigned char *)(IO_BASE + 0x116)	/* eeprom command register */

#define CBEIF	0x80
#define CBEIE   0x80
#define CCIF	0x40

#define EEPROM_BUSY (!(ESTAT&CCIF))

typedef volatile u16 eeblock;

static inline int eeprom_init(void){
	ECLKDIV = OSCCLK/MAX_EEPROM_CLK;
	return 0;
}

static inline int eeprom_command(int command){
	ECMD = command;
	ESTAT |= CBEIF;
	return 0;
}

static inline int eeprom_modify(eeblock *address,eeblock data){
	if(EEPROM_BUSY)
		return -1;
	GENDEBUG("eeprom write %x to address %x\r\n",(long)data,(long)address); 	
	*address = data ;
	eeprom_command(SECTOR_MODIFY);	
	return 0;
}

#endif
