/***************************************************************************
                          mcontrol.h  - 
                          Modbus ISO/OSI level 7 protocol.
                             -------------------
    begin                : Thu March 28 2003
    email                : ngustavson@emacinc.com
 ***************************************************************************/
#ifndef MCONTROL_H
#define MCONTROL_H

#include <GNU_defs.h>
#include <realtime.h>
#include <ser.h>

 
//need to check on this number, 100 is just a guess
#define MAXPDUDATASIZE 100
//#define MAXPDUSIZE 100
#define PDU_AVAIL 5 //number of PDUs allocatable


typedef struct PDUstruct{
u8 function;
u8 data[MAXPDUDATASIZE];
u8 attributes;
int datasize;
}PDUstruct;

typedef struct PDU_Node{
struct PDU_Node *previous;
struct PDU_Node *next;
PDUstruct PDU;
}PDU_Node;

typedef struct PDU_List{
PDU_Node *head;
PDU_Node *tail;
int size;
}PDU_List; 

typedef struct modcounters
{
u16 bus_message;
u16 bus_CRC_error;
u16 slave_exception;
u16 slave_message;
u16 no_response;
u16 slave_NAK;
u16 slave_busy;
u16 character_overrun;
}modcounters;

/*
typedef struct mbconfig{
	u8 parity;    // parity
	u8 protocol;  // protocol ASCII or RTU
	u8 speed;     // baud rate
	u8 delim;    // the current delimiter	
	u16 address;   // address of the bus
}mbconfig;
*/

typedef struct Modbus_Port{
//	mbconfig config;
	int parity;    // parity
	int protocol;  // protocol ASCII or RTU
	int speed;     // baud rate
	int delim;    // the current delimiter	
	int address;   // address of the bus
	int port;      // port num 	
	int count;     // open count(should be 1 if open)
	int idle;      // idle count(not really used)
	int diagnostic;// diagnostic register
	u8 status;     // status flag register
//	char newdelim; // holding register for delim changes
/*
	int coilnum;
	int hregnum;
	int iregnum;
*/	
	modcounters counters;
	RTaskNode *RTUtasklet;
	RTIME t25;
	PDU_List PDUlist;
}Modbus_Port;

//#define MODBUS_PORTNUM PORT422

#define MODBUS_PORTNUM NUM_COMPORTS

//port status bits
#define ADDCHANGE 1
#define NEWDELIM  2
//LISTEN_ONLY 4 defined as diagnostic sub
#define CLEARLOG  8
#define RESTART   0x10


//PDU attributes
#define BROADCAST 1

//false function codes used for allocation
#define NULL_FUNCTION		 0
#define ALLOCATED			 1

//function codes
#define READ_COILS           1
#define READ_DISCRETE_INPUTS 2
#define READ_HOLDING_REGISTERS 3
#define READ_INPUT_REGISTERS 4
	#define RI_DATANUM_BYTES 1

#define WRITE_SINGLE_COIL    5
	#define ON_REQUEST   0xff00
	#define OFF_REQUEST  0

#define WRITE_SINGLE_REGISTER 6
	#define WRITE_SING_RES_SIZE   4

#define WRITE_MULTIPLE_COILS 15

#define WRITE_MULTIPLE_REGISTERS 0x10
        #define WRITEM_RESPONSE_BYTES 4
        #define WR_DATASTART 5

#define MASK_WRITE_REGISTER 0x16
	#define MASK_WRITE_SIZE 6

#define DIAGNOSTICS	8	
	//sub function codes
	#define RETURN_QUERY 0
	#define RESTART_COMM 1
	#define RETURN_DIAGN 2
	#define CH_ASCII_IND 3
	#define LISTEN_ONLY  4
	#define CLEAR_COUNT  0x0a 
	#define RETURN_BUSM  0x0b
	#define COMM_ERR_CNT 0x0c
	#define BUS_EXCP_CNT 0x0d
	#define SLV_MSG_CNT  0x0e
	#define SLV_NO_RESP  0x0f
	#define SLV_NAK_CNT  0x10
	#define SLV_BUSY_CNT 0x11
	#define RETRN_OVERRN 0x12
	#define CLEAR_OVERRN 0x14

//counter register defines

#define STARTCOUNT   1
#define TRIGBITS     6
#define ASTOPBIT     8
#define ARELOADBIT   0x10
#define COUNTENABLE  0x80

//config_register_defines
#define BAUD_RATE_BIT	    0x01
#define PARITY_TYPE_BIT     0x08
#define PARITY_ON_BIT	    0x10
#define PROTOCOL_BIT	    0x80

#define MODBUS_DEFAULT BAUD_RATE_BIT|PARITY_TYPE_BIT
#define MODBUS_ADDRESS_DEFAULT 2

//exception codes
#define ILLEGAL_FUNCTION     1
#define ILLEGAL_DATA_ADDRESS 2
#define ILLEGAL_DATA_VALUE   3

PDU_Node __attribute__((far)) *GetPDUnode(void);
void __attribute__((far)) DumpPDUQueue(Modbus_Port *modport);
int __attribute__((far)) Dump_Frames(Modbus_Port *modport);
int __attribute__((far)) PDU_exe(Modbus_Port *modport, PDUstruct *PDU);
int __attribute__((far)) EnQueue_PDU(PDU_Node *newnode, Modbus_Port *modport);
PDUstruct __attribute__((far)) *DeQueue_PDU(Modbus_Port *modport);
Modbus_Port __attribute__((far)) *Modbus_Device_Open(int port, int speed,int address,
	 int parity, int protocol,char delim);
int __attribute__((far)) Modbus_Diagnostic(Modbus_Port *modport,u8 *data, int datasize);
int  __attribute__((far)) Modbus_Slave_Control(Modbus_Port *modport);
int  __attribute__((far)) Modbus_Device_Close(Modbus_Port *modport);

/***************************************************************
 * Modbus Restart
 * Used to automate the restart of a modbus port
 * @param port Modbus_Port to start
 * @return pointer to the Modbus_Port structure
 */
static inline Modbus_Port *Modport_Restart(Modbus_Port *port){
	return(Modbus_Device_Open(port->port,port->speed,
		port->address,port->parity,port->protocol,port->delim));
}

#include <protocol/mserial.h>
static inline void print_modbus_state(int comport,Modbus_Port *port){
	ser_printf(comport,"address: %u\r\n",(long)port->address);
	ser_printf(comport,"protocol: %s\r\n",(port->protocol==RTU_PROTOCOL)?"RTU":"ASCII");
	ser_printf(comport,"speed: %u\r\n",(long)port->speed);
	ser_printf(comport,"delim: %x\r\n",(long)port->delim);
	
	if(port->parity==NO_PARITY)
		ser_printf(comport,"parity: OFF\r\n");
	else	
		ser_printf(comport,"parity: %s\r\n",(port->parity==EVEN_PARITY)?"EVEN":"ODD");
}

#endif






