#ifndef _MFUNCTIONS_H_
#define _MFUNCTIONS_H_

#include <GNU_defs.h>
#include <init.h>
#include <protocol/mcontrol.h>

//modbus virtual register type
typedef u16 mvregister;

#define VREGSIZE (sizeof(mvregister))

typedef int __attribute__((far))(*mvregister_function)(mvregister *);
//typedef int (*wregister_function)(u16);

typedef struct mvregister_array{
	mvregister_function *function;
	int length;
}mvregister_array;

static inline mvregister_array *set_array(mvregister_array *target,
		mvregister_function *source, int length){
	target->function = source;
	target->length = length;
	return target;						
							
}

/***************************************************************
 * rvregister
 * read from a virtual register
 */
static inline int rvregister(mvregister_array *regarray,int address,mvregister *data){
	mvregister ret;
	int status;
	
	if((address>=regarray->length)||(address<0))
		return ILLEGAL_DATA_ADDRESS;
	
	status = regarray->function[address](&ret);
	GENDEBUG("mvregister %u: = %u\r\n",(long)address,(long)ret); 
	//*data = bend2int((u8 *)&ret);
	//*data = int2bend((u8 *)&ret);
	*data = (mvregister)ret;
	GENDEBUG("bent data = %u\r\n",(long)*data); 
	return status;
}

/***************************************************************
 * wwrvregister
 * write to a virtual register
 */
static inline int wvregister(mvregister_array *regarray, 
		int address,mvregister *data){
	
	mvregister bentdata = bend2int((u8 *)data);
	
	if((address>=regarray->length)||(address<0))
		return ILLEGAL_DATA_ADDRESS;
	
	GENDEBUG("writing %u: = %u\r\n",(long)address,(long)bentdata); 
	
	return regarray->function[address](&bentdata);
}


static inline void ser_dump_array(int comport,mvregister_array *array){
	int regnum;
	mvregister data;
	for(regnum=0;regnum<array->length;regnum++){
		//rvregister(array,regnum,&data);
		array->function[regnum](&data);
		ser_printf(comport,"reg %u: %u\r\n",(long)regnum,(long)(int)data);
	}

}

static inline void ser_dump_array_hex(int comport,mvregister_array *array){
	int regnum;
	mvregister data;
	for(regnum=0;regnum<array->length;regnum++){
		//rvregister(array,regnum,&data);
		array->function[regnum](&data);
		ser_printf(comport,"reg %u: %x\r\n",(long)regnum,(long)data);
	}

}





/**
 * mwvregister
 * mask-write a virtual register
 */
static inline int mwvregister(mvregister_array *regarrayr, 
		mvregister_array *regarrayw,int address,
		mvregister and, mvregister or){
	
	int status;
	mvregister value;
	if((status = rvregister(regarrayr,
				address,(&value))))
		return status;

	value = (value|or)&and;
	
	return(status=wvregister(regarrayw,address,&value));		
}

mvregister_array  __attribute__((far)) *MWR_Array(mvregister_function *WR, int length);
mvregister_array  __attribute__((far)) *MWC_Array(mvregister_function *WCB, int length);
mvregister_array  __attribute__((far)) *MIRR_Array(mvregister_function *IRR, int length);
mvregister_array  __attribute__((far)) *MHRR_Array(mvregister_function *HRR, int length);
mvregister_array  __attribute__((far)) *MICR_Array(mvregister_function *ICR, int length);

#define MWR_SET(array) MWR_Array((mvregister_function *)array, sizeof(array)/sizeof(mvregister_function))
#define MWC_SET(array) MWC_Array((mvregister_function *)array, sizeof(array)/sizeof(mvregister_function))
#define MIRR_SET(array) MIRR_Array((mvregister_function *)array, sizeof(array)/sizeof(mvregister_function))
#define MHRR_SET(array) MHRR_Array((mvregister_function *)array, sizeof(array)/sizeof(mvregister_function))
#define MICR_SET(array) MICR_Array((mvregister_function *)array, sizeof(array)/sizeof(mvregister_function))

int __attribute__((far)) Write_regs(int address,int reg_num, u8 *data);
int __attribute__((far)) Write_Coils(int address,int coilnum, u8 *data);
int __attribute__((far)) Read_Iregs(int address,int reg_num, u8 *dataout);
int __attribute__((far)) Read_Hregs(int address,int reg_num, u8 *dataout);
int __attribute__((far)) Read_Coils(int address,int coilnum, u8 *dataout);
int __attribute__((far)) Switch_Coil(int coil,int command);
int __attribute__((far)) Modbus_Diagnostic(Modbus_Port *modport,u8 *data, int datasize);
int __attribute__((far)) Mask_Write_Register(mvregister address, mvregister and, mvregister or);
int __attribute__((far)) Read_Coils(int address,int coilnum, u8 *dataout);


#endif //_FUNCTIONS_H_
