/* Modbus_Ser.h
Modbus ISO/OSI level 2 protocol for
communication over a serial line.
Nathan Z. Gustavson 
ngustavson@emacinc.com
n_gustavson@yahoo.com
3/13/03
Emac.inc
*/
#ifndef MSERIAL_H
#define MSERIAL_H

#define ASCIISTART_FRAME ':'
#define ASCIISTART_STR   ":"
#define ASCIISTOP_FRAME  "\r\n"

#define RTU_PROTOCOL 0
#define ASCII_PROTOCOL 1

#define RTU_DATA_MAX 252
#define RTU_CRC_BYTES 2
#define RTU_ADDRESS_BYTES 1
#define RTU_FUNCTION_BYTES 1
#define RTU_FRAME_MIN  RTU_CRC_BYTES + RTU_FUNCTION_BYTES + RTU_ADDRESS_BYTES
#define RTU_FRAME_MAX  RTU_FRAME_MIN + RTU_DATA_MAX 

#define ASCII_DATA_MAX 504
#define ASCII_LRC_BYTES 2
#define ASCII_ADDRESS_BYTES 2
#define ASCII_FUNCTION_BYTES 2
#define ASCII_START_BYTES 1
#define ASCII_STOP_BYTES  2
#define ASCII_FRAME_MIN  ASCII_LRC_BYTES + ASCII_FUNCTION_BYTES + ASCII_ADDRESS_BYTES + ASCII_START_BYTES + ASCII_STOP_BYTES
#define ASCII_FRAME_MAX  ASCII_FRAME_MIN + ASCII_DATA_MAX 

#define PDU_DATA_MAX RTU_DATA_MAX

typedef struct RTU_Frame{
u8 address;
u8 function;
u8 *data;
int datasize;
u8 CRC[2];
}RTU_Frame;


typedef struct ASCII_Frame{
//const char *start;
char address[ASCII_ADDRESS_BYTES + 1];
char function[ASCII_FUNCTION_BYTES + 1];
//char *data;
char data[ASCII_FRAME_MAX];
int datasize;
char LRC[3];
const char *start;
const char *stop;
}ASCII_Frame;


void  __attribute__((far))ASCIIcallback(int port,void *arg);
void  __attribute__((far))RTUcallback(int port,void *arg);
//PDUstruct *ASCII2PDU(ASCII_Frame *frame);
//PDUstruct *ASCII2PDU(PDU_struct *PDU, ASCII_Frame *frame);
//PDUstruct *RTU2PDU(RTU_Frame *frame);
//PDUstruct *RTU2PDU(PDU_struct *PDU, RTU_Frame *frame);

unsigned short  __attribute__((far))CRC16 (u8 *puchMsg,unsigned short usDataLen );
int  __attribute__((far))DestroyPDU(PDUstruct *PDU);
u8  __attribute__((far))LRC(u8 *auchMsg, unsigned short usDataLen);
//RTU_Frame *RTU_Build_Frame(u8 address, u8 function, u8 *data,int datasize);
RTU_Frame __attribute__((far)) *RTU_Build_Frame(u8 address, u8 function,
	RTU_Frame *frame, u8 *data,int datasize);
int __attribute__((far)) RTU_Transmit_Frame(RTU_Frame *frame, int port);

//RTU_Frame *RTU_Receive_Frame(Modbus_Port *modport);
RTU_Frame __attribute__((far)) *RTU_Receive_Frame(RTU_Frame *frame,Modbus_Port *modport);

//ASCII_Frame *ASCII_Build_Frame(u8 address, u8 function,
//	ASCII_Frame *data,int datasize);

ASCII_Frame __attribute__((far)) *ASCII_Build_Frame(u8 address, u8 function, 
							ASCII_Frame *frame, u8 *data,int datasize);

//int ASCII_Transmit_Frame(ASCII_Frame *frame, int port);
int __attribute__((far)) ASCII_Transmit_Frame(ASCII_Frame *frame, char delim, int port);
//ASCII_Frame *ASCII_Receive_Frame(Modbus_Port *modport);
ASCII_Frame __attribute__((far)) *ASCII_Receive_Frame(ASCII_Frame *frame,Modbus_Port *modport);
int __attribute__((far)) DestroyFrame(int protocol,void *frame);

void __attribute__((far)) RTUframecomplete(taskdata port);

/***************************************************************
 * bend2int exchange high and low bytes of a 16 bit word
 * @param u8 pointer to the word to bend
 * @return the flipped word
 */
static inline int bend2int(u8 *bend)
{
int bent;

bent = bend[0];
bent<<=8;
bent+=bend[1];

return bent;
}

static inline int int2bend(u8 *bend)
{
int bent;

bent = bend[1];
bent<<=8;
bent+=bend[0];

return bent;
}



static inline char ctoa(u8 nibble)
{
if (nibble>9)
	return(nibble + 55);
else
	return(nibble + 48);
}

static inline void nwconvert(long data, char *asciiout, int size)
{
int i;

	for(i=(size-1);i>=0;i--)
	 {
	  asciiout[i] = ctoa(((u8)data&0x0F));
	  data>>=4;
	 }
} 

#endif

