/***************************************************************************
                          writeback.h  - 
                          writeback routines for 
						  committing data to a static disk 
                             -------------------
    begin                : Thu Nov 4 2005
    email                : ngustavson@emacinc.com
 ***************************************************************************/

#ifndef _WRITEBACK_H_
#define _WRITEBACK_H_
#include <stdio.h>
#include <eeprom.h>

#define DIRTY 	1

//hardware implementation specific routines
#define EEPROM_WRITEBACK
#ifdef EEPROM_WRITEBACK
typedef eeblock blocktype;

static inline blocktype DISKREAD(blocktype *address, int offset)
	{	return(address[offset]);}

static inline int DISKWRITE(blocktype *address,int offset,blocktype data)
	{	return(eeprom_modify(&address[offset],data));} 
	
#endif

typedef struct persistant_block{
	int size;			//number of data blocks
	int status;			//current state
	blocktype *cache;	//address of the cached data
	blocktype *disk;	//address of the data on the disk
	struct persistant_block *previous;
	struct persistant_block *next;
}persistant_block;

typedef struct persistant_block_list{
	struct persistant_block *head;
	struct persistant_block *tail;
	struct persistant_block *current;
	int offset;
	int size;
}persistant_block_list; 

static inline void init_list(persistant_block_list *list){
	list->head=list->tail=list->current=NULL;
	list->offset=list->size=0;
}

static inline void invalidate(persistant_block *block){
	block->status|=DIRTY;
}

void __attribute__((far)) swapin(persistant_block *block);
int __attribute__((far)) writeback(persistant_block_list *list);
void enqueue_block(persistant_block_list *list,persistant_block *block);

static inline persistant_block *next_dirty(persistant_block *block){
	persistant_block *start = block;
	
	if(block==NULL)
		return NULL;//invalid block, possibly an empty list

	do{
		if(block->status&DIRTY)
			return block;
		block = block->next;						
	}while(block!=start);
	
	return NULL;//no dirty blocks found
}

static inline int validate(persistant_block *block){
	int offset;
	for(offset=0;offset<block->size;offset++)
		if(block->cache[offset]!=DISKREAD(block->disk,offset))
			return 0;
	
	return 1;		
	} 

#endif //_WRITEBACK_H_
