#include <init.h>
#include <vt100.h>
#include "ipactest.h"

#define REVISION "2.0"

zerocross zerostructs[IOCNUMPORTS];

int rc()
{
int port = PORT232;
heartbeat(ON);
while(1){port=IpacTestProg(port);}
return 0;
}

void displaytime(taskdata privatedata)
{
extern RTIME systime;
displaydata *display = (displaydata *)privatedata;
timestruct time;
RTC_GetTime(&time);
RTdisable();
SAVE_CURSOR(display->port);
CURSPOS(display->port,display->line,display->column);
ser_printf(display->port,"%d/%d/%d  %d/%d/%d   ",(long)time.month,(long)time.date,(long)time.year,(long)time.hours,(long)time.minutes,(long)time.seconds);
RESTORE_CURSOR(display->port);
RTenable();
display->task = RTaddtask(displaytime,privatedata,(RTIME)(TIMEREFRESH + systime));
}


static int TestInterface (int port)
{
u8 sel[2] = {'Z',0};
NEWSCRN(port);
//const char *menu = "IPAC Test Program rev 1.1\r\n"__DATE__"\r\n\r\nA: Digital Input Readings\r\nB: Internal Analog to Digital Readings\r\nC: IOC PWMs\r\nD: IOC Counters\r\nE: Digital to Analog \r\nF: RTC\r\nG: Switch Serial Ports\r\nH: LCD control\r\n>";
ser_printf(port,"IPAC Test Program rev "REVISION"\r\n"__DATE__"\r\n\r\nA: Digital Input Readings\r\nB: Analog to Digital Readings\r\nC: IOC PWMs\r\n");
ser_printf(port,"D: IOC Counters\r\nE: Digital to Analog \r\nF: RTC\r\nG: Switch Serial Ports\r\nH: LCD control\r\n>");
//ser_printf(port,menu);
sel[0] = ser_getch(port);
NEWSCRN(port);
ser_printf(port,sel);
ser_printf(port,"\r\n");
return((int)sel[0]);
}

static int IpacTestDataInit(void)
{
int ic;
for(ic=0;ic<IOCNUMPORTS;ic++)
{
zerostructs[ic].zerocrossings = 0;
zerostructs[ic].lastzero = 0;
zerostructs[ic].frequency = 0;
}
return SUCCESS;
}

int IpacTestProg(int port)
{
char selection;
displaydata keydisplay, RTCdisplay;
IpacTestDataInit();
keydisplay.port = port;
keydisplay.line = 24;
keydisplay.column = 0;
RTCdisplay.port = port;
RTCdisplay.line = 23;
RTCdisplay.column = 0;

while(1)
{
displaytime(((taskdata)&RTCdisplay));
KeyCall(KeyDisplay,&keydisplay);
selection = TestInterface(port);
/*
Remove clock display and keydisplay during subprograms
ser_printf cannot be called recursively so only 1 screen refresh task can be active at a time.
*/
RTremove_task(RTCdisplay.task);
KeyCall(NULL,NULL);

switch(selection)
{
case 'a':
case 'A':
Disp_Digital_Input_Readings(port,1,1);
break;

case'b':
case'B':
Disp_Analog_to_Digital_Readings(port,1,1);
break;

case'c':
case'C':
PWM_Interface(port,1,1);
break;

case'd':
case'D':
Counter_Interface(port,1,1);
break;

case 'e':
case 'E':
DtoA_Interface(port,1,1);
break;

case 'f':
case 'F':
RTC_Interface(port,1,1);
break;

case 'g':
case 'G':
ser_printf(port,"Ipac Test Port switched, please connect to the other serial port\r\n");
if(port==PORT232)
  return PORT422;
else
  return PORT232;
break;

case 'h':
case 'H':
LCD_control(port,1,1);
break;

default :
ser_printf(port,"invalid selection\r\n");
break;
}
}
return 0;
}

void Display_Dig_Task(taskdata privatedata)
{
int port;
extern RTIME systime;
displaydata *display = (displaydata *)privatedata;
SAVE_CURSOR(display->port);
CURSPOS(display->port,display->line,display->column);

for(port=0;port<DIGITALPORTNUM;port++)
ser_printf(display->port,"%x  \t%x  \t%x  \r\n",(long)port,(long)Digital_in(port),(long)read_port_cfg(port));

display->task = RTaddtask(Display_Dig_Task,privatedata,(RTIME)(DIGREFRESH + systime));
RESTORE_CURSOR(display->port);
}


int Disp_Digital_Input_Readings(int serial, int line, int  column)
{
extern RTIME systime;
char control_line[20];
displaydata display;
display.port = serial;
display.column = column;
display.line = line+13;
while(1)
{
CLRSCR(serial);
CURSPOS(serial,line,column);
ser_printf(serial,"Digital Input Readings\r\n");
ser_printf(serial,"Digital ports are controlled with the format selection/command/data\r\n ");
ser_printf(serial,"commands are c-config,d-mask config,w-write,x-mask write\r\n");
ser_printf(serial,"Data is the data or configuration byte\r\n");
ser_printf(serial,"selection is a bitmask of ports for mask commands and portnum for non-mask\r\n");
ser_printf(serial,"for example, to configure digital port 2 to be all outputs\r\n ");
ser_printf(serial,"type 2/c/0xff<enter>\r\n ");
ser_printf(serial,"To write 0xaa to digital ports 0 and 2\r\n ");
ser_printf(serial,"type 6/x/0xaa<enter>\r\n ");
ser_printf(serial,"type q<enter> to quit and return to the main menu\r\n\n\n");
ser_printf(serial,"port\tdata\tconfig\t\r\n");
CURSPOS(serial,line+10,column+1);
ser_printf(serial,">");
display.task = RTaddtask(Display_Dig_Task,(taskdata)&display,(RTIME)(DIGREFRESH + systime));
ser_getline(serial,control_line,sizeof(control_line),ECHO);
RTremove_task(display.task);
if(Digitalcommand(control_line)==-1)
  return 0;
}
return 0;
}


int Digitalcommand(char *line)
{
int argue;
char *token[3];
int channel,data;
char command;
for(argue=0;argue<3;argue++)
{
  if((token[argue]=strsep(&line,"/"))==NULL)
{
    //GENDEBUG("null token received\r\n");
    return -2;
}
  if(*token[argue]=='q')
    return -1;
}
channel = strtoul(token[0],NULL,0);
command = *token[1];
data = strtoul(token[2],NULL,0);
switch(command)
{
case 'w':
Digital_out(data,channel);
break;

case 'x' :
Digital_Mask_Write(data,channel);
break;

case 'c':
port_cfg(channel,data);
break;

case 'd' :
Digital_Mask_Cfg(data,channel);
break;

default :
return -2;
}

return 0;
}


void AtoDreadings(int module, u16 *data, volatile u8 *status, void *privatedata)
{
extern RTIME systime;
int channel;
displaydata *display = privatedata;
CURSPOS(display->port,display->line,display->column);
ser_printf(display->port,"channel %d\t",(long)module);
for(channel=0;channel<8;channel++)
  ser_printf(display->port,"%x  \t",(unsigned long)data[channel]);
ser_printf(display->port,"\r");
RTaddtask(AtoDst_sample,module,(RTIME)(ATODREFRESH + systime));
//AtoDst_sample(module);
}

int Disp_Analog_to_Digital_Readings(int serial, int line, int column)
{
char quitchar;
extern RTIME systime;
displaydata display[3];
display[0].port = serial;
display[0].column = column;
display[0].line = line+1;
display[1].port = serial;
display[1].column = column;
display[1].line = line+2;
display[2].port = serial;
display[2].column = column;
display[2].line = line+3;
CLRSCR(serial);
CURSPOS(serial,line,column);
ser_printf(serial,"Analog to Digital Readings ");
ser_printf(serial,"press q to quit\r\n");
Install_AtoDcallback(0,AtoDreadings,&display[0]);
Install_AtoDcallback(1,AtoDreadings,&display[1]);
display[2].task = RTaddtask(Display_ExtAn_Task,(taskdata)&display[2],(RTIME)(ATODREFRESH + systime));
AtoDst_sample(0);
AtoDst_sample(1);
while((quitchar=ser_getch(serial))!='q') ;
Remove_AtoDcallback(0);
Remove_AtoDcallback(1);
RTremove_task(display[2].task);
return 0;
}

void Display_ExtAn_Task(taskdata privatedata){
extern RTIME systime;
int channel;
displaydata *display = (displaydata *)privatedata;
AtoDsample sample;
LTC1290_Read(&sample);
CURSPOS(display->port,display->line,display->column);
ser_printf(display->port,"Ext channel \t");
for(channel=0;channel<8;channel++)
  ser_printf(display->port,"%x  \t",(unsigned long)sample.channel[channel]);
ser_printf(display->port,"\r");
RTaddtask(Display_ExtAn_Task,(taskdata)display,(RTIME)(ATODREFRESH + systime));
}


int PWM_Interface(int port,int line,int column)
{
extern PWMdatastruct PWMdata[PWMSYS];
int pwm;
char control_line[50];
int cont_ret = 0;
CLRSCR(port);
while(1)
{
CLRSCR(port);
CURSPOS(port,line,column);
//GENDEBUG("strtoul test, 262 = %d\r\n",(long)strtoul("0x106",NULL,0));
ser_printf(port,"PWM menu\r\n ");
ser_printf(port,"PWMs are controlled with the format num/freq/duty\r\n ");
ser_printf(port,"for example, to set PWM 1 to 1000 Hz with a 75% duty cycle\r\n ");
ser_printf(port,"type 1/1000/75<enter>\r\n ");
ser_printf(port,"type q<enter> to quit and return to the main menu\r\n\n");
ser_printf(port,"pwm\tfreq\tduty\t\r\n");
for(pwm=0;pwm<PWMSYS;pwm++)
ser_printf(port,"%d\t%d\t%d\t\r\n",(long)pwm,(long)PWMdata[pwm].frequency,(long)PWMdata[pwm].duty);
ser_printf(port,">");
ser_getline(port,control_line,sizeof(control_line),ECHO);
if((cont_ret=PWMcommand(control_line))==-1)
  return 0;//q command pressed
}
return 0;
}

int PWMcommand(char *line)
{
int argue;
char *token[3];
for(argue=0;argue<3;argue++)
{
  if((token[argue]=strsep(&line,"/"))==NULL)
{
    //GENDEBUG("null token received\r\n");
    return -2;
}
  if(*token[argue]=='q')
    return -1;
}

PWM_Ipac(strtoul(token[0],NULL,0),strtoul(token[2],NULL,0),strtoul(token[1],NULL,0));
return 0;
}




int Counter_Interface(int port,int line,int column)
{
extern RTIME systime;
char control_line[50];
displaydata display;

display.port = port;
display.column = column;
display.line = line+12;


CLRSCR(port);


//GENDEBUG("strtoul test, 262 = %d\r\n",(long)strtoul("0x106",NULL,0));
while(1)
{
CLRSCR(port);
CURSPOS(port,line,column);
ser_printf(port,"Counter menu\r\n ");
ser_printf(port,"Counters are controlled with the format num/trigger/load/flags\r\n ");
ser_printf(port,"possible triggers are 1-rising, 2-falling, or 3-both\r\n");
ser_printf(port,"possible flags are 0 - none, 2-reload, 4-autostop, 6-autoload-stop \r\n");
ser_printf(port,"ex: to set counter 1 trigger on rising edge, start at 100 and roll over at zero\r\n ");
ser_printf(port,"type 1/1/100/0<enter>\r\n ");
ser_printf(port,"type q<enter> to quit and return to the main menu\r\n");
ser_printf(port,">\r\n\n");
ser_printf(port,"count\tvalue\ttrig\tflags\tzeros\tfrequency\r\n");

CURSPOS(port,line + 7,column+1);
display.task = RTaddtask(Display_Count_Task,(taskdata)&display,(RTIME)(COUNTREFRESH + systime));
ser_getline(port,control_line,sizeof(control_line),ECHO);
RTremove_task(display.task);
if((Countcommand(control_line))==-1)
  return 0;//q command pressed

}//while loop
return 0;//function return
}



static char *TrigString(int trigger)
{
switch(trigger)
{
case RISEE:
return "Rise";

case FALLE:
return "Fall";

case ANYE:
return "Both";
}
return " ";
}

static char *FlagString(int flags)
{
switch(flags)
{
case ARELOAD:
return "ALoad";

case ASTOP:
return "AStop";

case (ARELOAD|ASTOP):
return "S-RS";
}
return " ";
}


void Display_Count_Task(taskdata privatedata)
{
extern RTIME systime;
extern Countdatastruct CountData[IOCNUMPORTS];
displaydata *display = (displaydata *)privatedata;
int counter;

SAVE_CURSOR(display->port);
CURSPOS(display->port,display->line,display->column);

for(counter=0;counter<IOCNUMPORTS;counter++)
ser_printf(display->port,"%d\t%d\t%s\t%s\t%d\t%d     \r\n",(long)counter,(long)ReadCounter(counter),TrigString(CountData[counter].trigger),FlagString(CountData[counter].flags),(long)zerostructs[counter].zerocrossings,(long)zerostructs[counter].frequency);

display->task = RTaddtask(Display_Count_Task,privatedata,(RTIME)(COUNTREFRESH + systime));
RESTORE_CURSOR(display->port);
}


void ZeroCount(int channel, void *privatedata)
{
extern RTIME systime;
zerocross *zeros = privatedata;
RTIME elapsed = systime - zeros->lastzero;
RTIME start = ((RTIME)CountStart(channel))*((RTIME)1000);

elapsed = elapsed/1000;

//GENDEBUG("elapsed = %d start = %d\r\n",(long)elapsed, (long)start);

if(elapsed!=0)
zeros->frequency = start/elapsed;
else
zeros->frequency = 0;

zeros->zerocrossings++;
zeros->lastzero =  systime;
}



int Countcommand(char *line)
{
extern RTIME systime;
int argue;
char *token[4];
int ic;
for(argue=0;argue<4;argue++)
{
  if((token[argue]=strsep(&line,"/"))==NULL)
{
    return -2;
}
  if(*token[argue]=='q')
    return -1;
}

ic = strtoul(token[0],NULL,0);
zerostructs[ic].zerocrossings = 0;
zerostructs[ic].lastzero = systime;
zerostructs[ic].frequency = 0;
Counter_Ipac(ic,strtoul(token[1],NULL,0), strtoul(token[2],NULL,0),ZeroCount,&zerostructs[ic], strtoul(token[3],NULL,0));
return 0;
}

int DtoA_Interface(int port,int line,int column)
{
extern DtoAdatastruct DtoAdata[DTOANUM];
int dta;
char control_line[50];
int cont_ret = 0;
CLRSCR(port);
while(1)
{
CLRSCR(port);
CURSPOS(port,line,column);
ser_printf(port,"DtoA menu\r\n ");
ser_printf(port,"DtoAs are controlled with the format num/value/\r\n ");
ser_printf(port,"for example, to set DtoA 1 to 100%\r\n ");
ser_printf(port,"type 1/100<enter>\r\n ");
ser_printf(port,"type q<enter> to quit and return to the main menu\r\n\n");
ser_printf(port,"DtoA\tOutput%\r\n");
for(dta=0;dta<DTOANUM;dta++)
ser_printf(port,"%d\t%d\r\n",(long)dta,(long)DtoAdata[dta].output);
ser_printf(port,">");
ser_getline(port,control_line,sizeof(control_line),ECHO);
if((cont_ret=DtoAcommand(control_line))==-1)
  return 0;//q command pressed
}
return 0;
}


int DtoAcommand(char *line)
{
int argue;
char *token[2];
int port,percent;
for(argue=0;argue<2;argue++)
{
  if((token[argue]=strsep(&line,"/"))==NULL)
{
    return -2;
}
  if(*token[argue]=='q')
    return -1;
}

port = strtoul(token[0],NULL,0);
percent = strtoul(token[1],NULL,0);

DtoA_Set(port, percent);
return 0;
}




const u8 KeyMatrix[KEYROW][KEYCOL] =
{
{'1','2','3','C','Z','Z'},/*row0*/
{'4','5','6','D','Z','Z'},/*row1*/
{'7','8','9','E','Z','Z'},/*row2*/
{'A','0','B','F','Z','Z'},/*row3*/
};


void KeyDisplay(void *privatedata)
{
u8 key;
int row;
int column;
char keychar[2];
displaydata *display = privatedata;
keychar[1] = 0;//create null terminated string
while(Keyrx(1,&key));//get last row and column position from key fifo
row = GETROW(key);
column = GETCOL(key);//bottom nibble
keychar[0] = KeyMatrix[row][column];
RTdisable();
SAVE_CURSOR(display->port);
CURSPOS(display->port,display->line,display->column);
ser_printf(display->port,"Keypad pressed %s",keychar);
RESTORE_CURSOR(display->port);
RTenable();
}


int RTC_Interface(int port,int line,int column)
{
displaydata RTCdisplay;
int menu;
char control_string[40];
char *control;
timestruct time;
RTCdisplay.column = column;
RTCdisplay.line = line;
RTCdisplay.port = port;
while(1)
{
control = control_string;
CLRSCR(port);
CURSPOS(port,line+2,column);
displaytime(((taskdata)&RTCdisplay));
ser_printf(port,"RTC control\r\n");
ser_printf(port,"A: set time\r\n");
ser_printf(port,"Q: to quit and return to the main menu\r\n");
ser_printf(port,">");
menu = ser_getch(port);
RTremove_task(RTCdisplay.task);/*stop displaying RT data because we are going to write to it*/
switch(menu)
{
case 'A':
case 'a':
ser_printf(port,"\r\n\r\nenter new time  hours/min/sec/month/date/day/year\r\n> ");
ser_getline(port,control_string,sizeof(control_string),ECHO);
time.hours = strtoul(strsep(&control,"/"),NULL,0);
time.minutes = strtoul(strsep(&control,"/"),NULL,0);
time.seconds = strtoul(strsep(&control,"/"),NULL,0);
time.month = strtoul(strsep(&control,"/"),NULL,0);
time.date = strtoul(strsep(&control,"/"),NULL,0);
time.day = strtoul(strsep(&control,"/"),NULL,0);
time.year = strtoul(strsep(&control,"/"),NULL,0);
RTC_SetTime(&time);
break;

case 'Q':
case 'q':
return 0;
}
}
return 0;
}

int LCD_control(int port,int line,int column)
{
int command;
char LCDchar;
int position;
char buffer[20];
char *cline;

while(1)
{
cline = buffer;
CLRSCR(port);
CURSPOS(port,line,column);
ser_printf(port,"The LCD Control panel\r\n");
ser_printf(port,"A: Clear screen\r\n");
ser_printf(port,"B: Home\r\n");
ser_printf(port,"C: Type\r\n");
ser_printf(port,"D: Set Position\r\n");
ser_printf(port,"E: Backlight\r\n");
ser_printf(port,"F: Change number of lines\r\n");
ser_printf(port,"Q: return to main menu\r\n");

switch((command=ser_getch(port)))
{
case 'a':
case 'A':
LCD_Home(1);
break;

case 'b':
case 'B':
LCD_Home(0);
break;

case 'c':
case 'C':
CLRSCR(port);
CURSPOS(port,line,column);
ser_printf(port,"Typed characters will echo to the LCD display\r\n");
ser_printf(port,"hit # to return to the main menu\r\n");
while((LCDchar=ser_getch(port))!='#')
LCD_Putchar(LCDchar);
break;

case 'd':
case 'D':
CLRSCR(port);
CURSPOS(port,line,column);
position = LCD_Getpos();
ser_printf(port,"current cursor position is %d,%d\r\n",(long)(position>>8),(long)(position&0x00ff));
ser_printf(port,"enter new cursor positon as x,y\r\n");
ser_getline(port,cline,sizeof(buffer),ECHO);
position = strtoul(strsep(&cline,","),NULL,0);
position<<=8;
position += strtoul(strsep(&cline,","),NULL,0);
LCD_Setpos((position>>8), (position&0x00ff));
break;

case 'e':
case 'E':
CLRSCR(port);
CURSPOS(port,line,column);
ser_printf(port,"N=on,F=off \r\n");
switch((LCDchar=ser_getch(port)))
{
case 'n':
case 'N':
LCD_Backlight(ON);
break;

case 'f':
case 'F':
LCD_Backlight(OFF);
break;
}

break;

case 'f':
case 'F':
CLRSCR(port);
CURSPOS(port,line,column);
ser_printf(port,"enter 2 or 4 for 2 or 4 line mode\r\n");
switch((LCDchar=ser_getch(port)))
{
case '2':
LCD_SWLine_Mode(2);
break;

case '4':
LCD_SWLine_Mode(4);
break;
}
break;

case 'q':
case 'Q':
return 0;
break;
}
}
return 0;
}



