/***************************************************************************
                          redirection.c  -  Rebuilt Interrupt Routing
                             -------------------
    begin                : Wed March 29 2006
    email                : support@emacinc.com
 
 	This file can be used to rebuild and replace the indirection object, which
 	is normally just copied in from the kernel directory.
	The file is distributed as an exact copy of the indirection.c used to 
	build the kernel object. By modifying it and using the resulting object 
	instead, interrupts can be stolen from the kernel and used directly.
	Note that this can break some function calls, so using an integrated
	function call is usually better when it's possible. 
***************************************************************************/
#include <arch/param.h>
#include "indirection.h"

/*	dummy interrupt routine
 */ 

typedef void __attribute__((far))(*IOC_ISR)(int);
void __attribute__((far))SCI0isr(void);
void __attribute__((far))IRDAisr(void);
void __attribute__((far))RealIRQ(void);
void __attribute__((far))KeypadISR(void);
void __attribute__((far))SPI0_isr(void);
void __attribute__((far))RTCAlarm0ISR(void);
void __attribute__((far))RTCAlarm1ISR(void);

extern void __attribute__((far))_start (void);

/**
 * longjump to reset. 
 * Replacing this will make the board jump to a 
 * different initialization routine, don't replace this unless you want to
 * re-implement everything.
 */
void longjump(void){
_start();
}

/**
 * dummy interrupt routine, fills out unused vectors
 */
void dummit(void)	{
}

/**
 * Illegal operation routine
 */
void IllegalOP(void){
}


/**
 * CAN ISRs 
 */
#include <can.h>
extern can_module CAN_DEVICE[CANMOD_NUM];

/**
 * Can Wake up vector
 */
void CanWUP(void){
	//GENDEBUG("\r\nCAN Wake up \n\r");
	}


/**
 * Can rx vector, replacing these will break CAN system calls
 */
void MSCan0Rx_isr(void){CANrx_isr(&CAN_DEVICE[0]);}
void MSCan1Rx_isr(void){CANrx_isr(&CAN_DEVICE[1]);}
void MSCan2Rx_isr(void){CANrx_isr(&CAN_DEVICE[2]);}
void MSCan3Rx_isr(void){CANrx_isr(&CAN_DEVICE[3]);}
void MSCan4Rx_isr(void){CANrx_isr(&CAN_DEVICE[4]);}

/**
 * Can tx vector, replacing these will break CAN system calls
 */
void MSCan0Tx_isr(void){CANtx_isr(&CAN_DEVICE[0]);}
void MSCan1Tx_isr(void){CANtx_isr(&CAN_DEVICE[1]);}
void MSCan2Tx_isr(void){CANtx_isr(&CAN_DEVICE[2]);}
void MSCan3Tx_isr(void){CANtx_isr(&CAN_DEVICE[3]);}
void MSCan4Tx_isr(void){CANtx_isr(&CAN_DEVICE[4]);}

/**
 * Can error vector, replacing these will break CAN system calls
 */
void MSCan0Error_isr(void){CANerror_isr(&CAN_DEVICE[0]);}
void MSCan1Error_isr(void){CANerror_isr(&CAN_DEVICE[1]);}
void MSCan2Error_isr(void){CANerror_isr(&CAN_DEVICE[2]);}
void MSCan3Error_isr(void){CANerror_isr(&CAN_DEVICE[3]);}
void MSCan4Error_isr(void){CANerror_isr(&CAN_DEVICE[4]);}


/**
 * Real time interrupt vector replacing this will break the scheduler, and 
 * pretty much everything else. It could be added to realatively safely, but
 * it would probably be simpler to just use the scheduler.
 */
void Real_Time_Interrupt(void){
RealIRQ();
}

/**
 * eeprom vector, not currently used for anything
 */
void EEprom(void){
}
/**
 * SPI vector, replacing this will break non-blocking SPI functions.
 */
void SPI0(void){
SPI0_isr();
}

/**
 * Second SPI vector, not currently used
 */
void SPI2(void){
}

/**
 * PortH interrupt vectors
 * These general purpose interrupts are defined in the param.h file.
 */
#include <ds1305rtc.h>//this is somewhat out of place here
void PortH(void){
PortH_ISR();
}


/**
 * Internal AtoD calls. Replacing this vector will break 
 * the callback functionality of the AtoD channel.
 */
void __attribute__((far))AtoD0isr(void);
void __attribute__((far))AtoD1isr(void);

void ATD1(void){
AtoD1isr();
}

void ATD0(void){
AtoD0isr();
}

/**
 * Serial Port 0
 */
void SCI0(void){
SCI0isr();
}

/**
 * Serial Port 1
 */
void SCI1(void){
IRDAisr();
}

/* IOC interrupt handlers
All these interrupt handlers are implemented as function pointers,
and can be replaced safely by changing the pointer. This will still allow
normal IOC system calls to work (although calling them will change the vector back)
*/
extern IOC_ISR ioc_isr[8];

void IOC0(void){
ioc_isr[0](0);
}

void IOC1(void){
ioc_isr[1](1);
}

void IOC2(void){
ioc_isr[2](2);
}

void IOC3(void){
ioc_isr[3](3);
}

void IOC4(void){
ioc_isr[4](4);
}

void IOC5(void){
ioc_isr[5](5);
}

void IOC6(void){
ioc_isr[6](6);
}

void IOC7(void){
ioc_isr[7](7);
}




